"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.hasProposalDescriptionHash = void 0;
const react_1 = __importStar(require("react"));
const core_1 = require("@material-ui/core");
const components_1 = require("../../components");
const contexts_1 = require("../../contexts");
const DelegateVotesWidget_1 = __importDefault(require("../../widgets/DelegateVotesWidget"));
const PROPOSALS_PER_PAGE = 10;
// This check is used for some existing proposals in rinkeby.
const hasProposalDescriptionHash = (proposalDescription) => {
    return proposalDescription.includes(":Qm");
};
exports.hasProposalDescriptionHash = hasProposalDescriptionHash;
const ProposalsWidget = ({ onProposalCreationNavigate, onProposalDetailsNavigate, }) => {
    const { coreProxy, viewUtils } = (0, contexts_1.useStoreContext)();
    const { setLoading, handleCoreError } = (0, contexts_1.useLayoutContext)();
    const [proposals, setProposals] = (0, react_1.useState)([]);
    const [delegateVotesModalOpen, setDelegateVotesModalOpen] = (0, react_1.useState)(false);
    const [page, setPage] = (0, react_1.useState)(1);
    const [proposalCount, setProposalCount] = (0, react_1.useState)(0);
    const [hasEmptyState, setHasEmptyState] = (0, react_1.useState)(false);
    (0, react_1.useEffect)(() => {
        getProposals();
    }, [page]);
    (0, react_1.useEffect)(() => {
        getProposalsCount();
    }, []);
    const getProposals = () => {
        setLoading(true);
        coreProxy.governance
            .getProposals(page, PROPOSALS_PER_PAGE)
            .map((proposals) => {
            setProposals(proposals);
            setLoading(false);
        })
            .mapErr(handleCoreError);
    };
    const getProposalsCount = () => {
        setLoading(true);
        coreProxy.governance
            .getProposalsCount()
            .map((proposalCount) => {
            setProposalCount(proposalCount);
            if (!proposalCount) {
                setHasEmptyState(true);
            }
            setLoading(false);
        })
            .mapErr(handleCoreError);
    };
    const handleProposalsRefresh = () => {
        if (page === 1) {
            getProposals();
        }
        else {
            setPage(1);
        }
    };
    return (react_1.default.createElement(core_1.Box, null,
        react_1.default.createElement(components_1.GovernanceWidgetHeader, { label: "Proposals", rightContent: react_1.default.createElement(core_1.Box, { display: "flex", flexDirection: "row" },
                react_1.default.createElement(core_1.Box, { marginRight: "10px" },
                    react_1.default.createElement(components_1.GovernanceButton, { color: "primary", size: "medium", onClick: () => {
                            onProposalCreationNavigate && onProposalCreationNavigate();
                        }, variant: "outlined" }, "Create Proposal")),
                react_1.default.createElement(components_1.GovernanceButton, { color: "primary", size: "medium", onClick: () => {
                        setDelegateVotesModalOpen(true);
                    }, variant: "contained" }, "Delegate Voting")) }),
        hasEmptyState && (react_1.default.createElement(components_1.GovernanceEmptyState, { title: "No proposals found.", description: "Proposals submitted by community members will appear here." })),
        proposals.map((proposal) => {
            const proposalName = (0, exports.hasProposalDescriptionHash)(proposal.description)
                ? viewUtils.getProposalName(proposal.description)
                : proposal.description;
            return (react_1.default.createElement(components_1.GovernanceProposalListItem, { onClick: () => onProposalDetailsNavigate &&
                    onProposalDetailsNavigate(proposal.id), key: proposal.id, number: proposal.proposalNumber != null
                    ? (proposal.proposalNumber + 1).toString()
                    : "-", title: proposalName, status: proposal.state }));
        }),
        !!proposalCount && (react_1.default.createElement(components_1.GovernancePagination, { customPageOptions: {
                itemsPerPage: PROPOSALS_PER_PAGE,
                totalItems: proposalCount,
                currentPage: page,
            }, onChange: (_, page) => {
                setPage(page);
            } })),
        delegateVotesModalOpen && (react_1.default.createElement(DelegateVotesWidget_1.default, { onCloseCallback: () => setDelegateVotesModalOpen(false) }))));
};
exports.default = ProposalsWidget;
//# sourceMappingURL=ProposalsWidget.js.map